@@ -237,7 +237,7 @@ rm(list=ls())
     women <- which(dataset$MALE == 0)
     men <- which(dataset$MALE == 1)
     
-    # Find best matches.
+    # Find the best matches.
     pairs <- nroPair(data.x = trdata[women,], data.y = trdata[men,])
     print(head(pairs))
 
@@ -406,6 +406,40 @@ rm(list=ls())
     print(nroRcppMatrix(data=x, trim=TRUE))
 
 
+cat("\nnroRcppVector.Rd\n")
+rm(list=ls())
+
+    # Empty input reverts to default.
+    x <- nroRcppVector(data=NULL, default=NA, empty=TRUE)
+    print(x)
+    
+    # Empty input reverts to default, then to specified type.
+    x <- nroRcppVector(data=NULL, default=123, empty=TRUE, numeric=FALSE)
+    print(x)
+    
+    # Convert a logical vector to numbers.
+    x <- c(TRUE, TRUE, FALSE, TRUE)
+    names(x) <- c("a","b","c","d")
+    y <- nroRcppVector(data=x, numeric=TRUE)
+    print(y)
+
+
+cat("\nnroStatistic.Rd\n")
+rm(list=ls())
+
+    # Import data.
+    fname <- system.file("extdata", "finndiane.txt", package = "Numero")
+    dataset <- read.delim(file = fname)
+    
+    # Calculate centers.
+    mu <- nroStatistic(dataset, method = "center")
+    print(mu)
+    
+    # Calculate inter-quartile ranges.
+    iqr <- nroStatistic(dataset, method = "iqr")
+    print(iqr)
+
+
 cat("\nnroSummary.Rd\n")
 rm(list=ls())
 
@@ -481,21 +515,41 @@ rm(list=ls())
     fname <- system.file("extdata", "finndiane.txt", package = "Numero")
     dataset <- read.delim(file = fname)
     
-    # One dataset.
-    results <- numero.clean(dataset, identity = "INDEX")
-    
     # Create new versions for testing.
     dsA <- dataset[1:250, c("INDEX","AGE","MALE","uALB")]
     dsB <- dataset[151:300, c("INDEX","AGE","MALE","uALB","CHOL")]
     dsC <- dataset[201:500, c("INDEX","AGE","MALE","DIAB_RETINO")]
     
-    # Select only rows with a unique INDEX ('dsB' has none).
+    # Select all rows.
+    results <- numero.clean(a = dsA, b = dsB, c = dsC, identity = "INDEX")
+    cat("\n\nNo selection:\n")
+    print(nrow(results$a))
+    print(nrow(results$b))
+    print(nrow(results$c))
+    
+    # Select all rows and expanded for all identities.
     results <- numero.clean(a = dsA, b = dsB, c = dsC, identity = "INDEX",
-                            select = "distinct")
+                            select = "union")
+    cat("\n\nUnion:\n")
+    print(nrow(results$a))
+    print(nrow(results$b))
+    print(nrow(results$c))
     
     # Select only rows that are shared between all datasets.
     results <- numero.clean(a = dsA, b = dsB, c = dsC, identity = "INDEX",
-                            select = "shared")
+                            select = "intersection")
+    cat("\n\nIntersection:\n")
+    print(nrow(results$a))
+    print(nrow(results$b))
+    print(nrow(results$c))
+    
+    # Select only rows with a unique INDEX ('dsB' has none).
+    results <- numero.clean(a = dsA, b = dsB, c = dsC, identity = "INDEX",
+                            select = "exclusion")
+    cat("\n\nExclusion:\n")
+    print(nrow(results$a))
+    print(nrow(results$b))
+    print(nrow(results$c))
     
     # Add extra identification information.
     dsA$GROUP <- "A"
@@ -505,7 +559,11 @@ rm(list=ls())
     # Select rows with a unique identifier.
     results <- numero.clean(a = dsA, b = dsB, c = dsC,
                             identity = c("GROUP","INDEX"),
-                            select = "distinct")
+                            select = "exclusion")
+    cat("\n\nMulti-identities:\n")
+    print(nrow(results$a))
+    print(nrow(results$b))
+    print(nrow(results$c))
 
 
 cat("\nnumero.create.Rd\n")
