@@ -4,6 +4,16 @@
 
 #include "koho.local.h"
 
+/*
+ *
+ */
+string
+Engine::insert(const string& key, const mdsize unit,
+	       const mdreal value) {
+  vector<mdreal> array(1, value);
+  return this->insert(key, unit, array);
+}
+
 /*
  *
  */
